pub struct Register { /* private fields */ }Expand description
A Register on the SAFE Network
Implementations
Sourceimpl Register
impl Register
Sourcepub fn new(owner: PublicKey, meta: XorName, permissions: Permissions) -> Self
pub fn new(owner: PublicKey, meta: XorName, permissions: Permissions) -> Self
Create a new Register
Sourcepub fn bytes(&self) -> Result<Vec<u8>, Error>
pub fn bytes(&self) -> Result<Vec<u8>, Error>
Returns a bytes version of the Register used for signing Use this API when you want to sign a Register withtout providing a secret key to the Register API
Sourcepub fn address(&self) -> &RegisterAddress
pub fn address(&self) -> &RegisterAddress
Return the address.
Sourcepub fn permissions(&self) -> &Permissions
pub fn permissions(&self) -> &Permissions
Return the permission.
Sourcepub fn check_register_op(&self, op: &RegisterOp) -> Result<(), Error>
pub fn check_register_op(&self, op: &RegisterOp) -> Result<(), Error>
Check if a register op is valid for our current register