SignedRegister

Struct SignedRegister 

pub struct SignedRegister { /* private fields */ }
A Signed Register on the SAFE Network This cryptographically secure version of the Register is used to make sure that the data cannot be tampered with

Implementations

Source

impl SignedRegister

pub fn new( register: Register, signature: Signature, ops: BTreeSet<RegisterOp>, ) -> Self

Create a new SignedRegister

pub fn base_register(&self) -> &Register

Return the base register. This is the register before any operations have been applied.

pub fn verify(&self) -> Result<(), Error>

Verfies a SignedRegister

pub fn verify_with_address(&self, address: RegisterAddress) -> Result<(), Error>

pub fn merge(&mut self, other: &Self) -> Result<(), Error>

Merge two SignedRegisters

pub fn verified_merge(&mut self, other: &Self) -> Result<(), Error>

Merge two SignedRegisters but verify the incoming content Significantly slower than merge, use when you want to trust but verify the other

pub fn address(&self) -> &RegisterAddress

Return the address.

pub fn owner(&self) -> PublicKey

Return the owner of the data.

pub fn add_op(&mut self, op: RegisterOp) -> Result<(), Error>

Check and add an Op to the SignedRegister

pub fn ops(&self) -> &BTreeSet<RegisterOp>

Returns the reference to the ops list