pub struct SignedRegister { /* private fields */ }Expand description
A Signed Register on the SAFE Network This cryptographically secure version of the Register is used to make sure that the data cannot be tampered with
Implementations
Sourceimpl SignedRegister
impl SignedRegister
Sourcepub fn new(
register: Register,
signature: Signature,
ops: BTreeSet<RegisterOp>,
) -> Self
pub fn new( register: Register, signature: Signature, ops: BTreeSet<RegisterOp>, ) -> Self
Create a new SignedRegister
Sourcepub fn base_register(&self) -> &Register
pub fn base_register(&self) -> &Register
Return the base register. This is the register before any operations have been applied.
pub fn verify_with_address(&self, address: RegisterAddress) -> Result<(), Error>
Sourcepub fn verified_merge(&mut self, other: &Self) -> Result<(), Error>
pub fn verified_merge(&mut self, other: &Self) -> Result<(), Error>
Merge two SignedRegisters but verify the incoming content
Significantly slower than merge, use when you want to trust but verify the other
Sourcepub fn address(&self) -> &RegisterAddress
pub fn address(&self) -> &RegisterAddress
Return the address.
Sourcepub fn add_op(&mut self, op: RegisterOp) -> Result<(), Error>
pub fn add_op(&mut self, op: RegisterOp) -> Result<(), Error>
Check and add an Op to the SignedRegister
Sourcepub fn ops(&self) -> &BTreeSet<RegisterOp>
pub fn ops(&self) -> &BTreeSet<RegisterOp>
Returns the reference to the ops list